## code for location data used in PAG et al "Testing the conflict-cohesion hypothesis: effects of simulated territorial intrusions on metrics of social cohesion in banded mongooses (Mungos mungo)."
library(ctmm)
library(move)
library(raster)
library(dplyr)
library(lubridate)

setwd("C:/Users/Patrick/Dropbox (Personal)/Work/Research/BMRP/Ethology_Cohesion/Manuscript/Codes_data_for_submission/")

#read in GPS data from GPS collars - mongoose movements
Mongoose<-read.csv("collar_GPS_data.csv")
#read in dates and times of experiments
dates<-read.csv("days_and_dates.csv", header=T)
names(dates)[2]<-"date"
dates$date<-as.Date(dates$date,format="%d/%m/%Y")

#subset to timeframe
Mongoose$date <- as.Date(Mongoose$date, format= "%d/%m/%Y") #ensure date format is correct
#subset to individual packs, as dates vary per pack
oneB<-subset(Mongoose, Mongoose$pack=="1B") 
oneH<-subset(Mongoose, Mongoose$pack=="1H")
twenty6<-subset(Mongoose, Mongoose$pack=="26")
two<-subset(Mongoose, Mongoose$pack=="P2")
eleven<-subset(Mongoose, Mongoose$pack=="11")

#subset dates file for each pack
oneHdates<-subset(dates, dates$Pack=="1H")
oneBdates<-subset(dates, dates$Pack=="1B")
elevendates<-subset(dates, dates$Pack=="11")
twenty6dates<-subset(dates, dates$Pack=="26")
twodates<-subset(dates, dates$Pack=="P2")

#merge dates with GPS data
newdataH<-merge(oneH, oneHdates, all.x=TRUE)
newdataB<-merge(oneB, oneBdates, all.x=TRUE) 
newdata11<-merge(eleven, elevendates, all.x=TRUE) 
newdata26<-merge(twenty6, twenty6dates, all.x=TRUE)
newdata2<-merge(two, twodates, all.x=TRUE) 

#Merge back to one dataset
collar.data<-rbind(newdataH, newdataB, newdata11, newdata26, newdata2)
collar.data$date.time<-as.POSIXct(collar.data$date.time,format="%d/%m/%Y %H:%M",tz="UTC") #ensure correct datetime format
collar.data <- collar.data[order(collar.data$pack, collar.data$date.time),] #order by date within pack
collar.data$date<-as.POSIXct(collar.data$date,format="%d/%m/%Y",tz="UTC") #ensure date is in correct format
collar.data$date<-as.Date(collar.data$date,format="%d/%m/%Y") #convert date to other format

#Read in GPS breadcrumbs from tablets
tabgps<-read.csv("tablet_GPS_data.csv", header=T)
tabgps$ID<-as.character(tabgps$ID) #ensure ID is not a factor

#Custom function for extracting collar data and tablet GPS data from the correct day to match the presentation, create 3 month home range using ctmm, plot home ranges and presentation location, and read out.
plot_homerange_collar=function(RoundID, RoundTime, PackName, DayID, tab.data, col.data, JpegFile){
  library(dplyr)
  tablet.data.current<-tab.data[tab.data$ID==RoundTime,] #subset tablet GPS to experimental trial
  #get presentation location
  tab.data.point<-tablet.data.current[1,] #take the first available GPS location that corresponsds to the experimental trial (closest in time to the presentation)
  tab.data.point$time<-as.POSIXct(tab.data.point$time,format="%d/%m/%Y %H:%M",tz="UTC") #ensure datetime format correct
  #create move object of this point
  tab.data.point.moved <- move(x=tab.data.point$long,
                               y=tab.data.point$lat,
                               time=as.POSIXct(tab.data.point$time,format="%d-%m-%Y %H:%M:%S",tz="UTC"),
                               data=tab.data.point,
                               proj=CRS("+proj=longlat +datum=WGS84"),
                               sensor="GPS",
                               removeDuplicatedTimestamps=TRUE)
  #Select data for creating a home range
  collar.data.current<-subset(col.data, col.data$pack==PackName) #subset collar data to pack
  collar.data.current.3month<-collar.data.current %>% 
    filter(between(date, subset(dates$date, dates$Day==DayID) - months(3), subset(dates$date, dates$Day==DayID))) #subset three months before date of presentation
  detach(package:dplyr) #remove dplyr to use functions masked in plyr
  library(plyr) #use plyr
  #3 month home range calculation in ctmm
  current.3month <- collar.data.current.3month[order(collar.data.current.3month$pack, collar.data.current.3month$date.time),] #order the data by pack and then time
  current.3month_telemetry<-rename(current.3month, c("latitude" = "location.lat", "longitude"="location.long", "pack"="individual.local.identifier", "date.time"="timestamp")) #rename columns to match what ctmm expects
  current.3month_telemetry<-as.telemetry(current.3month_telemetry) #create a telemetry object
  GUESS_current_3month <- ctmm.guess(current.3month_telemetry,interactive=FALSE) #Select relevant ctmm model
  FITS_current.3month <- ctmm.select(current.3month_telemetry,GUESS_current_3month, level=1) #Select relevant ctmm model
  current.3month_akde <- akde(current.3month_telemetry, FITS_current.3month) #Create autocorrelated kernel density estimate using telemetry and ctmm model
  rast_current.3month<-raster(current.3month_akde,DF="CDF") #create a raster of the ctmm home range using Cumulative Distribution Function (CDF)
  print("3 Month HR Done") #lets you know its working - takes some time
  #transform coordinates to same CRS as raster
  tab.data.point.transformed <- spTransform(tab.data.point.moved, CRS(projection(rast_current.3month))) #transform the presentation location to the same CRS
  plot(current.3month_akde, level.UD=0.50, main=RoundTime) #plot the ctmm home range at a 50% boundary level
  points(x = tab.data.point.transformed@coords[1], y = tab.data.point.transformed@coords[2], pch=19) #add the location as a point on the plot
  jpeg(JpegFile, width = 12, height = 10, units = 'in', res = 600) #export the plot to the file specified
  plot(current.3month_akde, level.UD=0.50, main=RoundTime) #plot the ctmm home range at a 50% boundary level
  points(x = tab.data.point.transformed@coords[1], y = tab.data.point.transformed@coords[2], pch=19) #add the location as a point on the plot
  dev.off() #closes export
}

#Run the custom function for each experimental trial:
#replace the filename with desired end location for each plot. a plot will also show in R studio plot window. 
plot_homerange_collar("1BR1", "oneBR1con AM", "1B", "oneBR1con", tabgps, collar.data, "\1BR1 AM.jpeg")
plot_homerange_collar("1BR1", "oneBR1con PM", "1B", "oneBR1con", tabgps, collar.data, "\1BR1 PM.jpeg")
plot_homerange_collar("1BR2", "oneBR2con AM", "1B", "oneBR2con", tabgps, collar.data, "\1BR2 AM.jpeg")
plot_homerange_collar("1BR2", "oneBR2con PM", "1B", "oneBR2con", tabgps, collar.data, "\1BR2 PM.jpeg")
plot_homerange_collar("1BR3", "oneBR3con PM", "1B", "oneBR3con", tabgps, collar.data, "\1BR3 PM.jpeg")
plot_homerange_collar("1BR4", "oneBR4con PM", "1B", "oneBR4con", tabgps, collar.data, "\1BR4 PM.jpeg")
plot_homerange_collar("1BR5", "oneBR5con AM", "1B", "oneBR5con", tabgps, collar.data, "\1BR5 AM.jpeg")
plot_homerange_collar("1BR5", "oneBR5con PM", "1B", "oneBR5con", tabgps, collar.data, "\1BR5 PM.jpeg")
plot_homerange_collar("1BR6", "oneBR6con AM", "1B", "oneBR6con", tabgps, collar.data, "\1BR6 AM.jpeg")
plot_homerange_collar("1BR6", "oneBR6con PM", "1B", "oneBR6con", tabgps, collar.data, "\1BR6 PM.jpeg")

plot_homerange_collar("1BC1", "oneBC1con AM", "1B", "oneBC1con", tabgps, collar.data, "\1BC1 AM.jpeg")
plot_homerange_collar("1BC1", "oneBC1con PM", "1B", "oneBC1con", tabgps, collar.data, "\1BC1 PM.jpeg")
plot_homerange_collar("1BC2", "oneBC2con AM", "1B", "oneBC2con", tabgps, collar.data, "\1BC2 AM.jpeg")
plot_homerange_collar("1BC2", "oneBC2con PM", "1B", "oneBC2con", tabgps, collar.data, "\1BC2 PM.jpeg")
plot_homerange_collar("1BC3", "oneBC3con AM", "1B", "oneBC3con", tabgps, collar.data, "\1BC3 AM.jpeg")
plot_homerange_collar("1BC4", "oneBC4con PM", "1B", "oneBC4con", tabgps, collar.data, "\1BC4 PM.jpeg")
plot_homerange_collar("1BC5", "oneBC5con AM", "1B", "oneBC5con", tabgps, collar.data, "\1BC5 AM.jpeg")
plot_homerange_collar("1BC5", "oneBC5con PM", "1B", "oneBC5con", tabgps, collar.data, "\1BC5 PM.jpeg")
plot_homerange_collar("1BC6", "oneBC6con AM", "1B", "oneBC6con", tabgps, collar.data, "\1BC6 AM.jpeg")
plot_homerange_collar("1BC6", "oneBC6con PM", "1B", "oneBC6con", tabgps, collar.data, "\1BC6 PM.jpeg")

#1H
plot_homerange_collar("1HR1", "oneHR1con AM", "1H", "oneHR1con", tabgps, collar.data, "\1HR1 AM.jpeg")
plot_homerange_collar("1HR1", "oneHR1con PM", "1H", "oneHR1con", tabgps, collar.data, "\1HR1 PM.jpeg")
plot_homerange_collar("1HR3", "oneHR3con AM", "1H", "oneHR3con", tabgps, collar.data, "\1HR3 AM.jpeg")
plot_homerange_collar("1HR3", "oneHR3con PM", "1H", "oneHR3con", tabgps, collar.data, "\1HR3 PM.jpeg")
plot_homerange_collar("1HR4", "oneHR4con AM", "1H", "oneHR4con", tabgps, collar.data, "\1HR4 AM.jpeg")
plot_homerange_collar("1HR4", "oneHR4con PM", "1H", "oneHR4con", tabgps, collar.data, "\1HR4 PM.jpeg")
plot_homerange_collar("1HR5", "oneHR5con AM", "1H", "oneHR5con", tabgps, collar.data, "\1HR5 AM.jpeg")
plot_homerange_collar("1HR5", "oneHR5con PM", "1H", "oneHR5con", tabgps, collar.data, "\1HR5 PM.jpeg")
plot_homerange_collar("1HR6", "oneHR6con AM", "1H", "oneHR6con", tabgps, collar.data, "\1HR6 AM.jpeg")

plot_homerange_collar("1HC1", "oneHC1con AM", "1H", "oneHC1con", tabgps, collar.data, "\1HC1 AM.jpeg")
plot_homerange_collar("1HC1", "oneHC1con PM", "1H", "oneHC1con", tabgps, collar.data, "\1HC1 PM.jpeg")
plot_homerange_collar("1HC2", "oneHC2con PM", "1H", "oneHC2con", tabgps, collar.data, "\1HC2 PM.jpeg")
plot_homerange_collar("1HC3", "oneHC3con AM", "1H", "oneHC3con", tabgps, collar.data, "\1HC3 AM.jpeg")
plot_homerange_collar("1HC3", "oneHC3con PM", "1H", "oneHC3con", tabgps, collar.data, "\1HC3 PM.jpeg")
plot_homerange_collar("1HC4", "oneHC4con AM", "1H", "oneHC4con", tabgps, collar.data, "\1HC4 AM.jpeg")
plot_homerange_collar("1HC4", "oneHC4con PM", "1H", "oneHC4con", tabgps, collar.data, "\1HC4 PM.jpeg")
plot_homerange_collar("1HC5", "oneHC5con AM", "1H", "oneHC5con", tabgps, collar.data, "\1HC5 AM.jpeg")
plot_homerange_collar("1HC5", "oneHC5con PM", "1H", "oneHC5con", tabgps, collar.data, "\1HC5 PM.jpeg")
plot_homerange_collar("1HC6", "oneHC6con AM", "1H", "oneHC6con", tabgps, collar.data, "\1HC6 AM.jpeg")
plot_homerange_collar("1HC6", "oneHC6con PM", "1H", "oneHC6con", tabgps, collar.data, "\1HC6 PM.jpeg")

plot_homerange_collar("11R1", "elevenR1con PM", "11", "elevenR1con", tabgps, collar.data, "\11R1 PM.jpeg")
plot_homerange_collar("11R2", "elevenR2con PM", "11", "elevenR2con", tabgps, collar.data, "\11R2 PM.jpeg")
plot_homerange_collar("11R3", "elevenR3con AM", "11", "elevenR3con", tabgps, collar.data, "\11R3 AM.jpeg")
plot_homerange_collar("11R3", "elevenR3con PM", "11", "elevenR3con", tabgps, collar.data, "\11R3 PM.jpeg")
plot_homerange_collar("11R4", "elevenR4con AM", "11", "elevenR4con", tabgps, collar.data, "\11R4 AM.jpeg")
plot_homerange_collar("11R4", "elevenR4con PM", "11", "elevenR4con", tabgps, collar.data, "\11R4 PM.jpeg")

plot_homerange_collar("11C1", "elevenC1con AM", "11", "elevenC1con", tabgps, collar.data, "\11C1 AM.jpeg")
plot_homerange_collar("11C2", "elevenC2con AM", "11", "elevenC2con", tabgps, collar.data, "\11C2 AM.jpeg")
plot_homerange_collar("11C2", "elevenC2con PM", "11", "elevenC2con", tabgps, collar.data, "\11C2 PM.jpeg")
plot_homerange_collar("11C3", "elevenC3con AM", "11", "elevenC3con", tabgps, collar.data, "\11C3 AM.jpeg")
plot_homerange_collar("11C3", "elevenC3con PM", "11", "elevenC3con", tabgps, collar.data, "\11C3 PM.jpeg")

plot_homerange_collar("2R1", "twoR1con AM", "P2", "twoR1con", tabgps, collar.data, "\2R1 AM.jpeg")
plot_homerange_collar("2R1", "twoR1con PM", "P2", "twoR1con", tabgps, collar.data, "\2R1 PM.jpeg")
plot_homerange_collar("2R2", "twoR2con AM", "P2", "twoR2con", tabgps, collar.data, "\2R2 AM.jpeg")
plot_homerange_collar("2R2", "twoR2con PM", "P2", "twoR2con", tabgps, collar.data, "\2R2 PM.jpeg")
plot_homerange_collar("2R3", "twoR3con AM", "P2", "twoR3con", tabgps, collar.data, "\2R3 AM.jpeg")
plot_homerange_collar("2R3", "twoR3con PM", "P2", "twoR3con", tabgps, collar.data, "\2R3 PM.jpeg")
plot_homerange_collar("2R4", "twoR4con AM", "P2", "twoR4con", tabgps, collar.data, "\2R4 AM.jpeg")

plot_homerange_collar("26R1", "twenty6R1con AM", "26", "twenty6R1con", tabgps, collar.data, "\26R1 AM.jpeg")
plot_homerange_collar("26R1", "twenty6R1con PM", "26", "twenty6R1con", tabgps, collar.data, "\26R1 PM.jpeg")
plot_homerange_collar("26R2", "twenty6R2con AM", "26", "twenty6R2con", tabgps, collar.data, "\26R2 AM.jpeg")
plot_homerange_collar("26R2", "twenty6R2con PM", "26", "twenty6R2con", tabgps, collar.data, "\26R2 PM.jpeg")

plot_homerange_collar("26C1", "twenty6C1con AM", "26", "twenty6C1con", tabgps, collar.data, "\26C1 AM.jpeg")
plot_homerange_collar("26C1", "twenty6C1con PM", "26", "twenty6C1con", tabgps, collar.data, "\26C1 PM.jpeg")
plot_homerange_collar("26C2", "twenty6C2con AM", "26", "twenty6C2con", tabgps, collar.data, "\26C2 AM.jpeg")
plot_homerange_collar("26C2", "twenty6C2con PM", "26", "twenty6C2con", tabgps, collar.data, "\26C2 PM.jpeg")
plot_homerange_collar("26C4", "twenty6C4con AM", "26", "twenty6C4con", tabgps, collar.data, "\26C4 AM.jpeg")
plot_homerange_collar("26C4", "twenty6C4con PM", "26", "twenty6C4con", tabgps, collar.data, "\26C4 PM.jpeg")
plot_homerange_collar("26C5", "twenty6C5con AM", "26", "twenty6C5con", tabgps, collar.data, "\26C5 AM.jpeg")
plot_homerange_collar("26C5", "twenty6C5con PM", "26", "twenty6C5con", tabgps, collar.data, "\26C5 PM.jpeg")
plot_homerange_collar("26C6", "twenty6C6con AM", "26", "twenty6C6con", tabgps, collar.data, "\26C6 AM.jpeg")
plot_homerange_collar("26C6", "twenty6C6con PM", "26", "twenty6C6con", tabgps, collar.data, "\26C6 PM.jpeg")
plot_homerange_collar("26C7", "twenty6C7con AM", "26", "twenty6C7con", tabgps, collar.data, "\26C7 AM.jpeg")
plot_homerange_collar("26C7", "twenty6C7con PM", "26", "twenty6C7con", tabgps, collar.data, "\26C7 PM.jpeg")
